==> haskell-bytes-0.17.4-118.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-bytes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bytes
version:              0.17.4
visibility:           public
id:                   bytes-0.17.4-Ie4bIJB4hX13MnlwcfQWOn
key:                  bytes-0.17.4-Ie4bIJB4hX13MnlwcfQWOn
license:              BSD-3-Clause
copyright:            Copyright (C) 2013-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             https://github.com/ekmett/bytes
synopsis:             Sharing code for serialization between binary and cereal
description:          Sharing code for serialization between binary and cereal.
category:             Data, Serialization
abi:                  0a832f2d2e50a80049facd1967c60223
exposed:              True
exposed-modules:
    Data.Bytes.Get Data.Bytes.Put Data.Bytes.Serial Data.Bytes.Signed
    Data.Bytes.VarInt

import-dirs:          /usr/lib/ghc-9.6.6/site-local/bytes-0.17.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/bytes-0.17.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/bytes-0.17.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytes
hs-libraries:         HSbytes-0.17.4-Ie4bIJB4hX13MnlwcfQWOn
depends:
    base-4.18.2.1 binary-0.8.9.1
    binary-orphans-1.0.5-1VCGcurzJlr6bEl6Wn9GAU bytestring-0.11.5.3
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK containers-0.6.7
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    scientific-0.3.8.0-3zIJLnW8aJ66FNwcOaEmTV text-2.0.2 time-1.12.2
    transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    void-0.7.3-DBkW9SEsEoE4KUGbU5pvgO

haddock-interfaces:   /usr/share/doc/haskell-bytes/html/bytes.haddock
haddock-html:         /usr/share/doc/haskell-bytes/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bytes-0.17.4-119-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-bytes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bytes
version:              0.17.4
visibility:           public
id:                   bytes-0.17.4-KxpygW1j5Fd25NrlyaW1Zf
key:                  bytes-0.17.4-KxpygW1j5Fd25NrlyaW1Zf
license:              BSD-3-Clause
copyright:            Copyright (C) 2013-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             https://github.com/ekmett/bytes
synopsis:             Sharing code for serialization between binary and cereal
description:          Sharing code for serialization between binary and cereal.
category:             Data, Serialization
abi:                  6553a274cfc395cfd48b7bf881567b43
exposed:              True
exposed-modules:
    Data.Bytes.Get Data.Bytes.Put Data.Bytes.Serial Data.Bytes.Signed
    Data.Bytes.VarInt

import-dirs:          /usr/lib/ghc-9.6.6/site-local/bytes-0.17.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/bytes-0.17.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/bytes-0.17.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytes
hs-libraries:         HSbytes-0.17.4-KxpygW1j5Fd25NrlyaW1Zf
depends:
    base-4.18.2.1 binary-0.8.9.1
    binary-orphans-1.0.5-2QdNlgpLYWR3AHIOi4WILQ bytestring-0.11.5.3
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK containers-0.6.7
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    scientific-0.3.8.0-JR5ijS18eRDLRLPoHGHkyW text-2.0.2 time-1.12.2
    transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    void-0.7.3-DBkW9SEsEoE4KUGbU5pvgO

haddock-interfaces:   /usr/share/doc/haskell-bytes/html/bytes.haddock
haddock-html:         /usr/share/doc/haskell-bytes/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
